@@ -123,7 +123,7 @@ usage (void)
   g_print ("\n");
 
   /* Note to Translators: Do not translate the TYPEs (WebBrowser, MailReader, TerminalEmulator),
-   * since the exo-helper utility will not accept localized TYPEs.
+   * since the xfce4-mime-helper utility will not accept localized TYPEs.
    */
   g_print ("%s\n", _("  WebBrowser       - The preferred Web Browser.\n"
                      "  MailReader       - The preferred Mail Reader.\n"
@@ -437,11 +437,7 @@ exo_open_uri (const gchar  *uri,
           && (strcmp (scheme, "ftp") == 0 || strcmp (scheme, "ftps") == 0))
         retval = exo_open_launch_category ("WebBrowser", uri);
       else
-#if GTK_CHECK_VERSION (3, 22, 0)
         retval = gtk_show_uri_on_window (NULL, uri, 0, error);
-#else
-        retval = gtk_show_uri (NULL, uri, 0, error);
-#endif
     }
 
   g_free (scheme);
